[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --distributed-even-if-your-workflow-isnt
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
# External Links
## Tutorials
### Short & Sweet
  * #### [Official Git Tutorial](https://git-scm.com/docs/gittutorial)
The official gittutorial man page is a good place to start.
  * #### [Git Immersion](http://gitimmersion.com/)
A guided tour that walks through the fundamentals of Git.


  * #### [Everyday Git](https://git-scm.com/docs/giteveryday)
Learn the basics with 20 of the most common commands.
  * #### [Backlog Git Tutorial](https://backlog.com/git-tutorial/)
It includes an introduction for complete beginners as well as hands-on tutorials for intermediate learners. ( [Japanese](https://backlog.com/git-tutorial/ja/) / [Korean](https://backlog.com/git-tutorial/kr/) / [Simplified Chinese](https://backlog.com/git-tutorial/cn/) / [Traditional Chinese](https://backlog.com/git-tutorial/tw/) / [Vietnamese](https://backlog.com/git-tutorial/vn/) )


### Diving Deeper
  * #### [Ry’s Git Tutorial](https://web.archive.org/web/20161121145226/http://rypress.com:80/tutorials/git/index)
A hands-on introduction to the entire Git porcelain.
  * #### [Git for Computer Scientists](http://eagain.net/articles/git-for-computer-scientists/)
A quick introduction to Git internals for people who aren't scared by words like Directed Acyclic Graph.
  * #### [Git Magic](http://www-cs-students.stanford.edu/~blynn/gitmagic/)
An alternative book with the source [online](https://github.com/blynn/gitmagic/tree/master).
  * #### [Git for Data Science](https://www.python4data.science/en/latest/productive/git/index.html)
Best practices and typical Git workflows for data science.


  * #### [Git for Designers](https://web.archive.org/web/20150301060509/http://hoth.entp.com/output/git_for_designers.html)
No knowledge of version control? No problem.
  * #### [git-draw](https://github.com/sensorflo/git-draw/wiki)
git-draw is a small tool that draws nearly the full content of a tiny git repository as a graph. It helps people with an engineering background learning Git's internals.
  * #### [GitHub Docs](https://docs.github.com/)
Guides on a variety of Git and GitHub related topics.


## Books
  * [![](https://git-scm.com/images/progit2.png)](https://git-scm.com/book)
#### [Pro Git](https://git-scm.com/book)
By Scott Chacon and Ben Straub
  * [![](https://www.manning.com/mcquaid/mcquaid_cover150.jpg)](https://www.manning.com/mcquaid/?a_aid=MikeMcQuaid&a_bid=5688bbf4)
#### [Git in Practice](https://www.manning.com/mcquaid/?a_aid=MikeMcQuaid&a_bid=5688bbf4)
By Mike McQuaid
  * [![](https://git-scm.com/images/books/git-in-the-trenches@2x.jpg)](https://cbx33.github.io/gitt/)
#### [Git in the Trenches](https://cbx33.github.io/gitt/)
By Peter Savage
  * [![](https://learning.oreilly.com/library/cover/9781491911204/250w)](http://gitforteams.com/)
#### [Git for Teams](http://gitforteams.com/)
By Emma Jane Hogbin Westby
  * [![](https://learning.oreilly.com/covers/urn:orm:book:9781098133900/400w/)](https://www.amazon.com/Learning-Git-Hands-Visual-Basics/dp/1098133919/)
#### [Learning Git: A Hands-On and Visual Guide to the Basics of Git](https://www.amazon.com/Learning-Git-Hands-Visual-Basics/dp/1098133919/)
By Anna Skoulikari


  * [![](https://git-scm.com/images/books/version-control-with-git@2x.jpg)](https://www.amazon.com/Version-Control-Git-collaborative-development/dp/0596520123)
#### [Version Control with Git, 2nd ed.](https://www.amazon.com/Version-Control-Git-collaborative-development/dp/1449316387)
By Jon Loeliger & Matthew McCullough
  * [![](https://git-scm.com/images/books/pragmatic-guide-to-git@2x.jpg)](https://www.pragprog.com/titles/pg_git/pragmatic-guide-to-git)
#### [Pragmatic Guide to Git](https://www.pragprog.com/titles/pg_git/pragmatic-guide-to-git)
By Travis Swicegood
  * [![](https://git-scm.com/images/books/pragmatic-version-control@2x.jpg)](https://www.pragprog.com/titles/tsgit/pragmatic-version-control-using-git)
#### [Pragmatic Version Control Using Git](https://www.pragprog.com/titles/tsgit/pragmatic-version-control-using-git)
By Travis Swicegood
  * [![](https://git-scm.com/images/books/git-internals@2x.jpg)](https://github.com/pluralsight/git-internals-pdf/releases/download/v2.0/peepcode-git.pdf)
#### [Git Internals Peepcode PDF](https://github.com/pluralsight/git-internals-pdf/releases/download/v2.0/peepcode-git.pdf)
By Scott Chacon
  * [![](https://www.manning.com/umali/umali_cover150.jpg)](https://www.manning.com/books/learn-git-in-a-month-of-lunches)
#### [Learn Git in a Month of Lunches](https://www.manning.com/books/learn-git-in-a-month-of-lunches)
By Rick Umali
  * [![](https://media.springernature.com/w153/springer-static/cover/book/9781484253137.jpg)](https://www.apress.com/book/9781484253120)
#### [Beginning Git and GitHub](https://www.apress.com/book/9781484253120)
By Mariot Tsitoara
  * [![](https://git-scm.com/images/books/boost-your-git-dx@2x.jpg)](https://adamchainz.gumroad.com/l/bygdx)
#### [Boost Your Git DX](https://adamchainz.gumroad.com/l/bygdx)
By Adam Johnson


## Videos
  * [![](https://git-scm.com/images/videos/linus@2x.jpg)](https://www.youtube.com/watch?v=4XpnKHJAok8)
#### [Tech Talk: Linus Torvalds on Git](https://www.youtube.com/watch?v=4XpnKHJAok8)
Linus Torvalds visits Google to share his thoughts on Git, the SCM system he created.


  * [![](https://git-scm.com/images/videos/introgit@2x.jpg)](https://www.youtube.com/watch?v=ZDR433b0HJY)
#### [Introduction to Git: Scott Chacon](https://www.youtube.com/watch?v=ZDR433b0HJY)
This talk introduces the Git Version Control System by looking at what Git is doing when you run the commands you need to do basic version control with it.


## Courses
  * #### [Versioned and reproducible storage of code and data](https://cusy.io/en/our-training-courses/versioned-and-reproducible-storage-of-code-and-data)
In this course you will learn how to create reproducible research results and write source code efficiently together.


  * #### [Versioned and reproducible storage of code and data](https://cusy.io/en/our-training-courses/versioned-and-reproducible-storage-of-code-and-data.html)
Three-day course on Git in data science


[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
